==> veracity-source-1.0.0.10517.tar.gz: veracity/src/js_tests/st_vc_hooks_04_replace.js <==
/*
Copyright 2010-2011 SourceGear, LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

load("vscript_test_lib.js");

function st_vc_hook_replace()
{
    this.testReplaceAsk = function test() 
    {
        var r1_name = sg.gid();
        var r1_path = pathCombine(tempDir, r1_name);
        if (!sg.fs.exists(r1_path)) {
          
            sg.fs.mkdir_recursive(r1_path);
        }
        sg.fs.cd(r1_path);
        
        // -------- create r1
        var o = sg.exec(vv, "new", r1_name);
        testlib.ok(o.exit_status == 0);

        o = sg.exec(vv, "user", "create", "ringo");
        testlib.ok(o.exit_status == 0);

        o = sg.exec(vv, "whoami", "ringo");
        testlib.ok(o.exit_status == 0);

        // -------- install a hook

		var dummyhook = 'function hook(params) { }';

        var repo = sg.open_repo(r1_name);
        repo.install_vc_hook(
                {
                    "interface" : "ask__wit__add_associations", 
                    "js" : dummyhook
                }
                );

        repo.install_vc_hook(
                {
                    "interface" : "broadcast__after_commit", 
                    "js" : dummyhook
                }
                );

		var hook = 'function hook(params) { return( { error: "something" } ); }';

        repo.install_vc_hook(
                {
                    "interface" : "ask__wit__add_associations", 
                    "js" : hook,
					"replace": true
                }
                );
		var db = new zingdb(repo, sg.dagnum.VC_HOOKS);
		var recs = db.query('hook', ['*'], "interface == 'ask__wit__add_associations'");

		testlib.equal(1, recs.length, "only one ask hook record after replace");
		
		recs = db.query('hook', ['*']);
		testlib.equal(3, recs.length, "non-specific hook count after replace");
        repo.close();
    };

	this.testIsInstalled = function()
	{
        var r1_name = sg.gid();
        var r1_path = pathCombine(tempDir, r1_name);
        if (!sg.fs.exists(r1_path)) {
          
            sg.fs.mkdir_recursive(r1_path);
        }
        sg.fs.cd(r1_path);
        
        // -------- create r1
        var o = sg.exec(vv, "new", r1_name);
        testlib.ok(o.exit_status == 0);

        o = sg.exec(vv, "user", "create", "ringo");
        testlib.ok(o.exit_status == 0);

        o = sg.exec(vv, "whoami", "ringo");
        testlib.ok(o.exit_status == 0);

        // -------- install a hook

		var dummyhook = 'function hook(params) { }';

        var repo = sg.open_repo(r1_name);

		try
		{
			var installedBefore = repo.vc_hooks_installed('ask__wit__add_associations');

			testlib.equal(1, installedBefore.length, "installed list before installation");

			if (installedBefore.length > 0)
				testlib.equal("scrum", installedBefore[0].module, "old module value");

			repo.install_vc_hook(
                {
                    "interface" : "ask__wit__add_associations", 
                    "js" : dummyhook,
					"module" : "bozo",
					"version": 3,
					"replace": true
                }
            );

			var installedAfter = repo.vc_hooks_installed('ask__wit__add_associations');

			if (testlib.equal(1, installedAfter.length, "installed list after installation"))
			{
				var details = installedAfter[0];
				
				testlib.equal("bozo", details.module, "module name");
				testlib.equal(3, details.version, "version");
			}
		}
		finally
		{
			if (repo)
				repo.close();
		}
	};
}

==> veracity-source-1.1.0.10565.tar.gz: veracity/src/js_tests/st_vc_hooks_04_replace.js <==
/*
Copyright 2010-2011 SourceGear, LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

load("vscript_test_lib.js");

function st_vc_hook_replace()
{
    this.testReplaceAsk = function test() 
    {
        var r1_name = sg.gid();
        var r1_path = pathCombine(tempDir, r1_name);
        if (!sg.fs.exists(r1_path)) {
          
            sg.fs.mkdir_recursive(r1_path);
        }
        sg.fs.cd(r1_path);
        
        // -------- create r1
        var o = sg.exec(vv, "init", r1_name, ".");
        testlib.ok(o.exit_status == 0);

        o = sg.exec(vv, "user", "create", "ringo");
        testlib.ok(o.exit_status == 0);

        o = sg.exec(vv, "whoami", "ringo");
        testlib.ok(o.exit_status == 0);

        // -------- install a hook

		var dummyhook = 'function hook(params) { }';

        var repo = sg.open_repo(r1_name);
        repo.install_vc_hook(
                {
                    "interface" : "ask__wit__add_associations", 
                    "js" : dummyhook
                }
                );

        repo.install_vc_hook(
                {
                    "interface" : "broadcast__after_commit", 
                    "js" : dummyhook
                }
                );

		var hook = 'function hook(params) { return( { error: "something" } ); }';

        repo.install_vc_hook(
                {
                    "interface" : "ask__wit__add_associations", 
                    "js" : hook,
					"replace": true
                }
                );
		var db = new zingdb(repo, sg.dagnum.VC_HOOKS);
		var recs = db.query('hook', ['*'], "interface == 'ask__wit__add_associations'");

		testlib.equal(1, recs.length, "only one ask hook record after replace");
		
		recs = db.query('hook', ['*']);
		testlib.equal(3, recs.length, "non-specific hook count after replace");
        repo.close();
    };

	this.testIsInstalled = function()
	{
        var r1_name = sg.gid();
        var r1_path = pathCombine(tempDir, r1_name);
        if (!sg.fs.exists(r1_path)) {
          
            sg.fs.mkdir_recursive(r1_path);
        }
        sg.fs.cd(r1_path);
        
        // -------- create r1
        var o = sg.exec(vv, "init", r1_name, ".");
        testlib.ok(o.exit_status == 0);

        o = sg.exec(vv, "user", "create", "ringo");
        testlib.ok(o.exit_status == 0);

        o = sg.exec(vv, "whoami", "ringo");
        testlib.ok(o.exit_status == 0);

        // -------- install a hook

		var dummyhook = 'function hook(params) { }';

        var repo = sg.open_repo(r1_name);

		try
		{
			var installedBefore = repo.vc_hooks_installed('ask__wit__add_associations');

			testlib.equal(1, installedBefore.length, "installed list before installation");

			if (installedBefore.length > 0)
				testlib.equal("scrum", installedBefore[0].module, "old module value");

			repo.install_vc_hook(
                {
                    "interface" : "ask__wit__add_associations", 
                    "js" : dummyhook,
					"module" : "bozo",
					"version": 3,
					"replace": true
                }
            );

			var installedAfter = repo.vc_hooks_installed('ask__wit__add_associations');

			if (testlib.equal(1, installedAfter.length, "installed list after installation"))
			{
				var details = installedAfter[0];
				
				testlib.equal("bozo", details.module, "module name");
				testlib.equal(3, details.version, "version");
			}
		}
		finally
		{
			if (repo)
				repo.close();
		}
	};
}
